.label {
  text-indent: 0.8em;
  font-size: 1.2em;
}

label {
  margin-bottom: 0;
}

.icon:before {
  color: white;
  cursor: pointer;
  /* Hide default checkbox */
  background: white;
  display: flex;
  align-items: center;
  height: inherit;
}
.icon + label {
  /* color: #bdc3c7; */
  cursor: pointer;
}

.done:before {
  content: "\e876";
  font-family: "Material Icons";
}

.done:checked:before {
  color: #5cb85c;
}
.done:checked + label {
  color: #5cb85c;
}

#root {
  padding: 20px 0;
}
