(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{28:function(e,t,n){"use strict";n.r(t);var c=n(7),a=n.n(c),o=n(15),s=n.n(o),l=n(0),i=n(3),r=n(1),d=n(2),u=n(17),b=n(13),j=n(8),p=function(e){Object(r.a)(n,e);var t=Object(d.a)(n);function n(e){var c;return Object(l.a)(this,n),(c=t.call(this,e)).render=function(){var e=c.props.args,t=e.body,n=e.labels;return c.makeTooltip(t,n)},c.state={},c}return Object(i.a)(n,[{key:"makeTooltip",value:function(e,t){var n=this;return Object(j.jsxs)(j.Fragment,{children:[Object(j.jsx)("div",{"data-for":"tooltip-select","data-event":"click focus","data-tip":"",onMouseUp:function(){var e,t=null===(e=window.getSelection())||void 0===e?void 0:e.toString();n.setState({selectedIndex:void 0,selectedText:(null===t||void 0===t?void 0:t.length)?t:void 0})},children:e}),Object(j.jsx)(u.a,{id:"tooltip-select",place:"right",globalEventOff:"mousedown",clickable:!0,children:this.state.selectedText?t.map((function(e,t){return Object(j.jsxs)(j.Fragment,{children:[Object(j.jsx)("input",{type:"checkbox",id:"item-".concat(t),className:"icon done",checked:n.state.selectedIndex===t,onChange:function(){return n.setState({selectedIndex:n.state.selectedIndex===t?void 0:t},(function(){b.a.setComponentValue([n.state.selectedText,n.state.selectedIndex])}))}}),Object(j.jsx)("label",{htmlFor:"item-".concat(t),className:"label",children:e}),Object(j.jsx)("br",{})]})})):null})]})}}]),n}(b.b),m=Object(b.c)(p);s.a.render(Object(j.jsx)(a.a.StrictMode,{children:Object(j.jsx)(m,{})}),document.getElementById("root"))}},[[28,1,2]]]);
//# sourceMappingURL=main.d35de175.chunk.js.map